==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/db/auth/authz_session_external_state_mock.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/status.h"
#include "mongo/db/auth/authz_session_external_state.h"

namespace mongo {

/**
 * Mock of the AuthzSessionExternalState class used only for testing.
 */
class AuthzSessionExternalStateMock : public AuthzSessionExternalState {
    AuthzSessionExternalStateMock(const AuthzSessionExternalStateMock&) = delete;
    AuthzSessionExternalStateMock& operator=(const AuthzSessionExternalStateMock&) = delete;

public:
    AuthzSessionExternalStateMock(AuthorizationManager* authzManager)
        : AuthzSessionExternalState(authzManager),
          _ignoreAuthChecksReturnValue(false),
          _allowLocalhostReturnValue(false),
          _serverIsArbiterReturnValue(false) {}

    virtual bool shouldIgnoreAuthChecks() const {
        return _ignoreAuthChecksReturnValue;
    }

    virtual bool shouldAllowLocalhost() const {
        return _allowLocalhostReturnValue;
    }

    virtual bool serverIsArbiter() const {
        return _serverIsArbiterReturnValue;
    }

    void setReturnValueForShouldIgnoreAuthChecks(bool returnValue) {
        _ignoreAuthChecksReturnValue = returnValue;
    }

    void setReturnValueForShouldAllowLocalhost(bool returnValue) {
        _allowLocalhostReturnValue = returnValue;
    }

    virtual void startRequest(OperationContext* opCtx) {}

private:
    bool _ignoreAuthChecksReturnValue;
    bool _allowLocalhostReturnValue;
    bool _serverIsArbiterReturnValue;
};

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/db/auth/authz_session_external_state_mock.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/status.h"
#include "mongo/db/auth/authorization_manager.h"
#include "mongo/db/auth/authz_session_external_state.h"
#include "mongo/db/operation_context.h"

namespace mongo {

/**
 * Mock of the AuthzSessionExternalState class used only for testing.
 */
class AuthzSessionExternalStateMock : public AuthzSessionExternalState {
    AuthzSessionExternalStateMock(const AuthzSessionExternalStateMock&) = delete;
    AuthzSessionExternalStateMock& operator=(const AuthzSessionExternalStateMock&) = delete;

public:
    AuthzSessionExternalStateMock(AuthorizationManager* authzManager)
        : AuthzSessionExternalState(authzManager),
          _ignoreAuthChecksReturnValue(false),
          _allowLocalhostReturnValue(false),
          _serverIsArbiterReturnValue(false) {}

    bool shouldIgnoreAuthChecks() const override {
        return _ignoreAuthChecksReturnValue;
    }

    bool shouldAllowLocalhost() const override {
        return _allowLocalhostReturnValue;
    }

    bool serverIsArbiter() const override {
        return _serverIsArbiterReturnValue;
    }

    void setReturnValueForShouldIgnoreAuthChecks(bool returnValue) {
        _ignoreAuthChecksReturnValue = returnValue;
    }

    void setReturnValueForShouldAllowLocalhost(bool returnValue) {
        _allowLocalhostReturnValue = returnValue;
    }

    void startRequest(OperationContext* opCtx) override {}

private:
    bool _ignoreAuthChecksReturnValue;
    bool _allowLocalhostReturnValue;
    bool _serverIsArbiterReturnValue;
};

}  // namespace mongo
